-- Vinny Loader window handler
-- coding: utf-8
import "Turbine.UI.Lotro"
import "Vinny.Common"

local backColor = Turbine.UI.Color( 1, 1, 1 )
local Small = VL_Opt and VL_Opt.small
local isize = Small and 16 or 32
VP = {
	{f="CampSite", i="CampFire"},
	{f="CookingRef", i="Cook"},
	{f="CraftMats", i="Craft"},
	{f="DailyTasks", i="Ring"},
	{f="EventTimer", i="Clock"},
	{f="LostLore", i="Book"},
	{f="RepRef", i="Barter"},
	{f="RuneUse", i="Rune"},
	{f="TravelRef", i="Stable"},
	{f="WarbandRef", i="Warband"},
}
AP = Turbine.PluginManager.GetAvailablePlugins()

function pFind(pt,name)
	for i,t in pairs(pt) do
		if t.Name==name then return true end
	end
end

local np = 0
for i,vp in ipairs(VP) do
	if pFind(AP,vp.f) then np = np+1
	else vp.i = nil end
end
if np==0 then print("Warning: No Vinny plugins found!") end

VL_Window = class( Turbine.UI.Window )

function VL_Window:Constructor()
	Turbine.UI.Window.Constructor( self )

	-- Position the window at the bottom left of the screen.
	self:SetSize( np*(isize+1)-1,isize )
	local y = Turbine.UI.Display.GetHeight()-isize
	self:SetPosition(0,y)
	self:SetBackColor( backColor )
	self:SetOpacity( .75 )
	self:SetZOrder(11000) -- Always on top
	self:SetVisible(true)

	-- load plugin icons
	local n = 0
	for i,vp in ipairs(VP) do
		if vp.i then
			local field = "icon"..i
			local icon = Turbine.UI.Button()
			self[field] = icon
			icon.vp = vp
			icon:SetSize( isize,isize )
			icon:SetParent(self)
			icon:SetPosition( n*(isize+1), 0)
			local path = "Vinny/"..vp.f.."/"..vp.i..".tga"
			if Small then path = "Vinny/VinnyLoader/Small/"..vp.i..".tga" end
			icon:SetBackground(path)
 			local name = vp.f
			icon.Click = function( sender,args )
				local reload = sender:IsAltKeyDown()
				local loaded = pFind(Turbine.PluginManager.GetLoadedPlugins(),name)
				if reload and loaded then
					print("Reloading "..name.." ...")
					Turbine.PluginManager.UnloadScriptState(name)
					loaded = false
				else print("Calling "..name.." ...") end
				if loaded then
					local pt = Plugins[name]
					if pt and pt.Open then pt.Open()
					else print(name.." is not updated for VL open action.") end
				else Turbine.PluginManager.LoadPlugin(name) end
			end
			n = n+1
		end
	end

    -- Setup window moving
    self.MouseDown = function(sender, args)
		sender.Start = args
    end

    self.MouseMove = function(sender, args)
        if sender.Start then
            sender:SetPosition(sender:GetLeft() + args.X-sender.Start.X,
								sender:GetTop() + args.Y-sender.Start.Y)
        end
    end

    self.MouseUp = function(sender, args)
        sender.Start = nil
    end

end
